Turtles: An Introduction to Objects and Classes
:::::::::::::::::::::::::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 2

   names4turtles.rst
   turtleFAP.rst
   multTurtles.rst
   repeatturtles.rst
   turtleGeom.rst
   patterns.rst
   stamp.rst
   functionsWithTurtles.rst
   summary.rst
   Exercises.rst
   mixedupcode.rst
   WriteCode.rst
